==> sign-center-api-0.0.2.2-20180428.084506-6-sources.jar: cn/com/duiba/sign/center/api/dto/SignPetActivityDto.java <==
package cn.com.duiba.sign.center.api.dto;


import cn.com.duiba.sign.center.api.enums.signpet.PetFeedTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * @author liugq
 * @date created in 2018/4/23
 * @description:
 */
public class SignPetActivityDto implements Serializable{
    private static final long serialVersionUID = -5836786643935952493L;

    /**
     * id
     **/
    private Long id;
    /**
     * 活动名称
     **/
    private String activityName;
    /**
     * 喂养类型
     */
    private PetFeedTypeEnum feedType;
    /**
     * 食物名称
     **/
    private String foodName;
    /**
     * 饭量
     */
    private String appetiteAmount;
    /**
     * 单次投掷粮食量限制
     **/
    private Integer feedAmountLimit;
    /**
     * 每天投掷次数限制
     **/
    private Integer feedCountLimit;
    /**
     * 吃饱状态保留时间（小时）
     **/
    private Integer fullStateDuration;
    /**
     * 创建时间
     **/
    private Date gmtCreate;
    /**
     * 修改时间
     **/
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public PetFeedTypeEnum getFeedType() {
        return feedType;
    }

    public void setFeedType(PetFeedTypeEnum feedType) {
        this.feedType = feedType;
    }

    public String getFoodName() {
        return foodName;
    }

    public void setFoodName(String foodName) {
        this.foodName = foodName;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getAppetiteAmount() {
        return appetiteAmount;
    }

    public void setAppetiteAmount(String appetiteAmount) {
        this.appetiteAmount = appetiteAmount;
    }

    public Integer getFeedAmountLimit() {
        return feedAmountLimit;
    }

    public void setFeedAmountLimit(Integer feedAmountLimit) {
        this.feedAmountLimit = feedAmountLimit;
    }

    public Integer getFeedCountLimit() {
        return feedCountLimit;
    }

    public void setFeedCountLimit(Integer feedCountLimit) {
        this.feedCountLimit = feedCountLimit;
    }

    public Integer getFullStateDuration() {
        return fullStateDuration;
    }

    public void setFullStateDuration(Integer fullStateDuration) {
        this.fullStateDuration = fullStateDuration;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> sign-center-api-0.0.3.3-20180505.051425-2-sources.jar: cn/com/duiba/sign/center/api/dto/SignPetActivityDto.java <==
package cn.com.duiba.sign.center.api.dto;


import cn.com.duiba.sign.center.api.enums.creditssign.SignActivityStatusEnum;
import cn.com.duiba.sign.center.api.enums.creditssign.SignStatusEnum;
import cn.com.duiba.sign.center.api.enums.signpet.PetFeedTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * @author liugq
 * @date created in 2018/4/23
 * @description:
 */
public class SignPetActivityDto implements Serializable{
    private static final long serialVersionUID = -5836786643935952493L;

    /**
     * id
     **/
    private Long id;
    /**
     * 活动名称
     **/
    private String activityName;
    /**
     * 喂养类型
     */
    private PetFeedTypeEnum feedType;
    /**
     * 食物名称
     **/
    private String foodName;
    /**
     * 饭量
     */
    private Integer appetiteAmount;
    /**
     * 单次投掷粮食量限制
     **/
    private Integer feedAmountLimit;
    /**
     * 每天投掷次数限制
     **/
    private Integer feedCountLimit;
    /**
     * 吃饱状态保留时间（小时）
     **/
    private Integer fullStateDuration;
    /**
     *
     */
    private SignActivityStatusEnum actStatus;
    /**
     * 创建时间
     **/
    private Date gmtCreate;
    /**
     * 修改时间
     **/
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public PetFeedTypeEnum getFeedType() {
        return feedType;
    }

    public void setFeedType(PetFeedTypeEnum feedType) {
        this.feedType = feedType;
    }

    public String getFoodName() {
        return foodName;
    }

    public void setFoodName(String foodName) {
        this.foodName = foodName;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public Integer getAppetiteAmount() {
        return appetiteAmount;
    }

    public void setAppetiteAmount(Integer appetiteAmount) {
        this.appetiteAmount = appetiteAmount;
    }

    public Integer getFeedAmountLimit() {
        return feedAmountLimit;
    }

    public void setFeedAmountLimit(Integer feedAmountLimit) {
        this.feedAmountLimit = feedAmountLimit;
    }

    public Integer getFeedCountLimit() {
        return feedCountLimit;
    }

    public void setFeedCountLimit(Integer feedCountLimit) {
        this.feedCountLimit = feedCountLimit;
    }

    public Integer getFullStateDuration() {
        return fullStateDuration;
    }

    public void setFullStateDuration(Integer fullStateDuration) {
        this.fullStateDuration = fullStateDuration;
    }

    public SignActivityStatusEnum getActStatus() {
        return actStatus;
    }

    public void setActStatus(SignActivityStatusEnum actStatus) {
        this.actStatus = actStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
